@@ -120,8 +120,10 @@ class Plugins(object):
                 raise e
             except IgnoreFileException as e:
                 raise e
+            except SystemError as e:
+                raise e
             except Exception as e:
-                binwalk.core.common.warning("%s.%s failed: %s" % (callback.__module__, callback.__name__, e))
+                binwalk.core.common.warning("%s.%s failed [%s]: '%s'" % (callback.__module__, callback.__name__, type(e), e))
 
     def _find_plugin_class(self, plugin):
         for (name, klass) in inspect.getmembers(plugin, inspect.isclass):
